The functions in this module are copied from secp256k1 because they can only be used when
compiled with the rand feature. But the other libraries need them as a dev-dependency for
cargo test also when rand is not enabled. Currently with cargo we can’t have a rand
dev-dependency and a non-rand dependency at the same time (see
https://github.com/rust-lang/cargo/issues/1796).